@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Retired;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-07-25'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 our @Module_Lists = (
     # list: Retired modules
@@ -54,6 +54,15 @@ issues and later wrote a clean-slate attempt `Unix::Passwd::File`.
 _
                 alternate_modules => ['Unix::Passwd::File'],
             },
+            {
+                module => 'Module::List::WithPath',
+                description => <<'_',
+
+Superseded by `PERLANCAR::Module::List`.
+
+_
+                alternate_modules => ['PERLANCAR::Module::List'],
+            },
         ],
     },
 );
@@ -73,7 +82,7 @@ Acme::CPANLists::PERLANCAR::Retired - Retired modules
 
 =head1 VERSION
 
-This document describes version 0.16 of Acme::CPANLists::PERLANCAR::Retired (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-29.
+This document describes version 0.17 of Acme::CPANLists::PERLANCAR::Retired (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-25.
 
 =head1 MODULE LISTS
 
@@ -119,6 +128,13 @@ issues and later wrote a clean-slate attempt C<Unix::Passwd::File>.
 
 Alternate modules: L<Unix::Passwd::File>
 
+=item * L<Module::List::WithPath>
+
+Superseded by C<PERLANCAR::Module::List>.
+
+
+Alternate modules: L<PERLANCAR::Module::List>
+
 =back
 
 =head1 HOMEPAGE
