@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Task::WorkingWithTree;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-07-25'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 my $text = <<'_';
 **Basics**
@@ -18,7 +18,8 @@ Memory-efficient tree nodes in Perl: `Tree::Node`.
 
 **Creating**
 
-`Tree::FromStruct`, `Tree::FromText`, `Tree::FromTextLines`, `Tree::Create`,
+`Tree::FromStruct`, `Tree::FromText`, `Tree::FromTextLines`,
+`Tree::Create::Callback`, `Tree::Create::Callback::ChildrenPerLevel`,
 `Tree::Create::Size`, `Tree::FromFS`.
 
 `Data::Random::Tree`.
@@ -73,7 +74,7 @@ Acme::CPANLists::PERLANCAR::Task::WorkingWithTree - Working with tree data struc
 
 =head1 VERSION
 
-This document describes version 0.16 of Acme::CPANLists::PERLANCAR::Task::WorkingWithTree (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-29.
+This document describes version 0.17 of Acme::CPANLists::PERLANCAR::Task::WorkingWithTree (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-25.
 
 =head1 MODULE LISTS
 
@@ -92,7 +93,8 @@ Memory-efficient tree nodes in Perl: C<Tree::Node>.
 
 B<Creating>
 
-C<Tree::FromStruct>, C<Tree::FromText>, C<Tree::FromTextLines>, C<Tree::Create>,
+C<Tree::FromStruct>, C<Tree::FromText>, C<Tree::FromTextLines>,
+C<Tree::Create::Callback>, C<Tree::Create::Callback::ChildrenPerLevel>,
 C<Tree::Create::Size>, C<Tree::FromFS>.
 
 C<Data::Random::Tree>.
@@ -134,7 +136,9 @@ C<Role::TinyCommons::Tree>.
 
 =item * L<Tree::FromTextLines>
 
-=item * L<Tree::Create>
+=item * L<Tree::Create::Callback>
+
+=item * L<Tree::Create::Callback::ChildrenPerLevel>
 
 =item * L<Tree::Create::Size>
 
